==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/outputs/FacebookChannelResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Facebook channel definition
 * @property channelName The channel name
 * Expected value is 'FacebookChannel'.
 * @property etag Entity Tag of the resource
 * @property location Specifies the location of the resource.
 * @property properties The set of properties specific to bot facebook channel
 * @property provisioningState Provisioning state of the resource
 */
public data class FacebookChannelResponse(
    public val channelName: String,
    public val etag: String? = null,
    public val location: String? = null,
    public val properties: FacebookChannelPropertiesResponse? = null,
    public val provisioningState: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.botservice.outputs.FacebookChannelResponse):
            FacebookChannelResponse = FacebookChannelResponse(
            channelName = javaType.channelName(),
            etag = javaType.etag().map({ args0 -> args0 }).orElse(null),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            properties = javaType.properties().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.botservice.kotlin.outputs.FacebookChannelPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            provisioningState = javaType.provisioningState(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/outputs/FacebookChannelResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Facebook channel definition
 * @property channelName The channel name
 * Expected value is 'FacebookChannel'.
 * @property etag Entity Tag of the resource
 * @property location Specifies the location of the resource.
 * @property properties The set of properties specific to bot facebook channel
 * @property provisioningState Provisioning state of the resource
 */
public data class FacebookChannelResponse(
    public val channelName: String,
    public val etag: String? = null,
    public val location: String? = null,
    public val properties: FacebookChannelPropertiesResponse? = null,
    public val provisioningState: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.botservice.outputs.FacebookChannelResponse): FacebookChannelResponse = FacebookChannelResponse(
            channelName = javaType.channelName(),
            etag = javaType.etag().map({ args0 -> args0 }).orElse(null),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            properties = javaType.properties().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.botservice.kotlin.outputs.FacebookChannelPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            provisioningState = javaType.provisioningState(),
        )
    }
}
